aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.World/Random.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'Minecraft.World/Random.cpp')
-rw-r--r--Minecraft.World/Random.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/Minecraft.World/Random.cpp b/Minecraft.World/Random.cpp
index 9176bf38..89903da8 100644
--- a/Minecraft.World/Random.cpp
+++ b/Minecraft.World/Random.cpp
@@ -1,4 +1,4 @@
-#include "stdafx.h"
+#include "stdafx.h"
#include "Random.h"
#include "System.h"
@@ -6,19 +6,19 @@ Random::Random()
{
// 4J - jave now uses the system nanosecond counter added to a "seedUniquifier" to get an initial seed. Our nanosecond timer is actually only millisecond accuate, so
// use QueryPerformanceCounter here instead
- __int64 seed;
+ int64_t seed;
QueryPerformanceCounter((LARGE_INTEGER *)&seed);
seed += 8682522807148012LL;
setSeed(seed);
}
-Random::Random(__int64 seed)
+Random::Random(int64_t seed)
{
setSeed(seed);
}
-void Random::setSeed(__int64 s)
+void Random::setSeed(int64_t s)
{
this->seed = (s ^ 0x5DEECE66DLL) & ((1LL << 48) - 1);
haveNextNextGaussian = false;
@@ -27,22 +27,22 @@ void Random::setSeed(__int64 s)
int Random::next(int bits)
{
seed = (seed * 0x5DEECE66DLL + 0xBLL) & ((1LL << 48) - 1);
- return (int)(seed >> (48 - bits));
+ return static_cast<int>(seed >> (48 - bits));
}
void Random::nextBytes(byte *bytes, unsigned int count)
{
for(unsigned int i = 0; i < count; i++ )
{
- bytes[i] = (byte)next(8);
+ bytes[i] = static_cast<byte>(next(8));
}
}
double Random::nextDouble()
{
- return (((__int64)next(26) << 27) + next(27))
- / (double)(1LL << 53);
+ return ((static_cast<int64_t>(next(26)) << 27) + next(27))
+ / static_cast<double>(1LL << 53);
}
double Random::nextGaussian()
@@ -56,7 +56,7 @@ double Random::nextGaussian()
{
double v1, v2, s;
do
- {
+ {
v1 = 2 * nextDouble() - 1; // between -1.0 and 1.0
v2 = 2 * nextDouble() - 1; // between -1.0 and 1.0
s = v1 * v1 + v2 * v2;
@@ -79,7 +79,7 @@ int Random::nextInt(int n)
if ((n & -n) == n) // i.e., n is a power of 2
- return (int)(((__int64)next(31) * n) >> 31); // 4J Stu - Made __int64 instead of long
+ return static_cast<int>((static_cast<int64_t>(next(31)) * n) >> 31); // 4J Stu - Made int64_t instead of long
int bits, val;
do
@@ -92,12 +92,12 @@ int Random::nextInt(int n)
float Random::nextFloat()
{
- return next(24) / ((float)(1 << 24));
+ return next(24) / static_cast<float>(1 << 24);
}
-__int64 Random::nextLong()
+int64_t Random::nextLong()
{
- return ((__int64)next(32) << 32) + next(32);
+ return (static_cast<int64_t>(next(32)) << 32) + next(32);
}
bool Random::nextBoolean()